@@ -15,7 +15,7 @@ class Reporting:
         Returns Report object with extra methotds
         """
         url = 'https://connect.tradedoubler.com/advertiser/report/transactions/export'
-        parameters = f'?format=csv&reportCurrencyCode={reportCurrencyCode}'
+        parameters = f'?format=json&reportCurrencyCode={reportCurrencyCode}'
         if fromDate == '':
             yesterday = datetime.now() - timedelta(8)
             yesterdayStr = datetime.strftime(yesterday, '%Y%m%d')
@@ -36,8 +36,7 @@ class Reporting:
             parameters += f'&{key}={value}'
         r = requests.get(url + parameters,
                          headers=self.con.get_request_header())
-        if r.status_code != 200:
-            raise ConnectionError(f'{r.text}\n\nquery: {url + parameters}')
+        self.con.handle_errors(r)
 
         return Report(r.json(), fromDate, toDate)
 
